@@ -1,5 +1,6 @@
 import tkinter as tk
 from tkinter import messagebox
+from tkinter import filedialog
 import freesasa
 from Bio.PDB import PDBParser
 from Bio.PDB import Selection
@@ -21,6 +22,8 @@ class GUI:
         self.frame = tk.Frame()
         self.frame.grid()
         self.title = master.title("AMIVA-F analysis of mutations in variants of human Filamin C")
+        #master.state = "500x1000"
+
         #master.state = "zoomed"
         """
         self.label1 = tk.Label(self.frame, text="Welcome to AMIVA-F, this script will aid you \n in preparing your"
@@ -95,11 +98,14 @@ class Entry_formular:
 
         self.header = tk.Label(self.frame, text="AMIVA-F analysis of mutations in variants of human Filamin C", font="Helvetica 16 bold", fg="black")
         self.header.grid(row=0, column=0, sticky="nswe", ipady=5)
-        self.label1 = tk.Label(self.frame, text="Please enter your mutation of interest into the entry field below. \n"
-                                                "Accepted format: e.g M82K \n"
-                                                "for Methionine being substituted by Lysine in the mutation at position"
-                                                " 82 according to UniProt Q14315")
-        self.label1.grid(row=1, column=0, ipadx=10, columnspan=2, sticky="news")
+        self.label1 = tk.Label(self.frame, text="Please enter your mutation of interest into the entry field below.")
+        self.label1.grid(row=1, column=0, columnspan=1, sticky="news")
+        self.label2 = tk.Label(self.frame, text="Accepted format: e.g M82K", font="Helvetica 12 bold")
+        self.label2.grid(row=2, column=0, ipadx=10, sticky="news")
+        self.label3 = tk.Label(self.frame, text="for Methionine (M) being mutated to Lysine (K) ")
+        self.label3.grid(row=3, column=0, ipadx=10, sticky="news")
+        self.label4 = tk.Label(self.frame, text="Allowed range:\n35 - 2725", font="helvetica 10 italic")
+        self.label4.grid(row=4, column=0, ipadx=10, columnspan=1, sticky="news")
 
         # entry + button for amino acid substitution
         self.entry1 = tk.Entry(self.frame)
@@ -158,6 +164,25 @@ class Entry_formular:
         pos = entry_start[1:-1]
 
 
+        entry_list = []   #we check the user input in case he puts random stuff like M8H2K instead of M82K
+        for entries in pos:
+            entry_list.append(entries)
+
+        for elements in entry_list:
+            if elements in atomchangelib:
+                print(elements)
+                messagebox.showerror("Invalid Input","Please enter a valid input")
+
+        if entry_start[-1] not in atomchangelib:  # if someone enters a non canonical aa we forbid that.
+            print(entry_start[-1])
+            messagebox.showerror("Invalid Input", "Please enter a valid input")
+        elif entry_start[0] not in atomchangelib:
+            print(entry_start[0])
+            messagebox.showerror("Invalid Input", "Please enter a valid input")
+
+
+
+
 
         # SASA calculations
         #self.msg1 = tk.messagebox.showinfo("Wildtype.pdb", "In order to generate your parameters"
@@ -243,7 +268,8 @@ class Entry_formular:
             pdbfile1 = "./FLNc_structures_pdb/FLNc_domain_24.pdb"
             domaininfo = "Ig24"
         else:
-            print("No structure available.")
+            msgerr = messagebox.showerror("Outside of FLNc position boundaries", "FlnC is only covered between 35 and 2725.\n"
+                                                                                 "Please enter a position that lies between these boundaries!")
 
         trans_aa_code_dict ={"A": "ALA", "G": "GLY", "S":"SER", "T":"THR", "C":"CYS", "M":"MET", "V":"VAL", "I":"ILE",
                              "L":"LEU", "F":"PHE", "Y": "TYR", "W": "TRP", "H": "HIS", "Q": "GLN", "E": "GLU", "N": "ASN",
@@ -251,7 +277,7 @@ class Entry_formular:
 
         reverse_trans_aa_dict = {"ALA": "A","GLY":"G" ,"SER":"S","THR":"T", "CYS":"C", "MET":"M", "VAL":"V", "ILE":"I",
                              "LEU":"L", "PHE":"F", "TYR": "Y", "TRP": "W", "HIS": "H", "GLN": "Q", "GLU": "E", "ASN": "N",
-                             "ASP": "D", "PRO": "P", "LYS": "K", "ARG": "K"}
+                             "ASP": "D", "PRO": "P", "LYS": "K", "ARG": "R"}
 
 
         with open(pdbfile1, "r") as pdbfile1_0:
@@ -260,6 +286,7 @@ class Entry_formular:
             resnamecheck = correct_atom_question.get_resname()
 
             """check if amino acid  entered is really amino acid at the correct position in the structure"""
+
             if resnamecheck == trans_aa_code_dict[aa_wt]:
                 pass
             else:
@@ -469,7 +496,8 @@ class Entry_formular:
                 entry_form.r3secstr.select()
         if int(pos) <= 2243 and int(pos) >= 2162:                   #this will mark the members of the IR region accordingly
             entry_form.r4secstr.select()
-
+        else:
+            entry_form.r4secstr.configure(state="disabled")
 
 
         # mutant SASA
@@ -505,6 +533,9 @@ class Entry_formular:
             elif round(dumpres[-2],2) < 20:
                 entry_form.r2sidechain.select()
 
+            if dumpres[-3] != "PRO" and dumpres[-3] != "GLY":       #we dont allow this to be selected if mutated aa is not gly or pro
+                entry_form.r3sidechain.configure(state="disabled")
+
             #sidechainorientation selector part stops
 
             #entering sap:
@@ -1006,10 +1037,10 @@ class Entryfield:
         self.frame5.grid(row=14, column=0,columnspan=3, pady= 10)
 
         self.clearbtn = tk.Button(self.frame5, text="Clear", command=self.clear_btn, borderwidth=4, width=10)
-        self.clearbtn.grid(row=1, column=3, sticky="w")
+        self.clearbtn.grid(row=1, column=5, sticky="we")
 
-        self.subbutnlbl = tk.Label(self.frame5, text="Click here to generate a prediction ready WEKA file -------->")
-        self.subbutnlbl.grid(row=1, column=0, ipadx=10)
+        #self.subbutnlbl = tk.Label(self.frame5, text="")
+        #self.subbutnlbl.grid(row=1, column=0, ipadx=10)
 
         self.subbtn = tk.Button(self.frame5, text="Generate \n template file", relief="ridge",
                                 borderwidth=4, command=self.outfile_handler_weka, bg="blue", fg="white")
@@ -1022,9 +1053,13 @@ class Entryfield:
         #                        command=lambda: self.mut_ids(mutation_ids), borderwidth=4)
         #self.mut_info.grid(row=1, column=6, pady=10)
         self.tutbutton = tk.Button(self.frame5, text="Read Tutorial", command=self.manual, borderwidth=4, width=20)
-        self.tutbutton.grid(row=1,column=4, sticky="w")
+        self.tutbutton.grid(row=1,column=6, sticky="we")
 
+        self.phosphoinfoadd = tk.Button(self.frame5, text="Inspect Phospholibrary", command=self.phosphoinfoadder, borderwidth=4)
+        self.phosphoinfoadd.grid(row=1,column=3, sticky="we")
 
+        self.bindinginfoadd = tk.Button(self.frame5, text="Inspect Bindinglibrary", command=self.bindinginfoadder, borderwidth=4)
+        self.bindinginfoadd.grid(row=1, column=4, sticky="we")
 
         """Start WEKA related stuff"""
 
@@ -1056,8 +1091,10 @@ class Entryfield:
         self.wekabtntrainset.grid(row=3, column=1, sticky="we")
         self.wekabtnmutantpdb = tk.Button(self.frame6_1, text="Clear", borderwidth=4, command=self.clearweka)
         self.wekabtnmutantpdb.grid(row=3, column=2, sticky="we")
-        self.wekabtnoutputfile = tk.Button(self.frame6_1, text="Outputfile mutation predictions", borderwidth=4, command=self.outputfilemutant)
+        self.wekabtnoutputfile = tk.Button(self.frame6_1, text="Save mutation prediction", borderwidth=4, command=self.outputfilemutant)
         self.wekabtnoutputfile.grid(row=3, column=3, sticky="we")
+        self.exitamiva = tk.Button(self.frame6_1, text="Exit AMIVA-F", command=self.exiting_amiva, borderwidth=4)
+        self.exitamiva.grid(row=3, column=4, sticky="we")
 
 
         #self.wekaentrytag = tk.Label(self.frame6, text="WEKA-Output", font="Helvetica 13")
@@ -1084,11 +1121,40 @@ class Entryfield:
         #self.wekaexplainlbl = tk.Label(self.frame6, text="The predicted outcome and its associated confidence\n of your submitted mutation are:")
         #self.wekaexplainlbl.grid(row=4, column=0, sticky="w")
 
+    def phosphoinfoadder(self):
+        window = tk.Toplevel(root)
+        window.title("Annotated Phosphosites")
+        s = tk.Scrollbar(window)
+        exp = tk.Text(window, width=100, height=30)
+        s.pack(side=tk.RIGHT, fill=tk.Y)
+        exp.pack(side=tk.LEFT, fill=tk.Y)
+        s.config(command=exp.yview)
+        exp.config(yscrollcommand=s.set)
+        with open("./Posttranslational_modifications_and_binding_partners/Posttranslational_modification_list.txt") as fh_phos:
+            phosphoinfo = fh_phos.readlines()
+            for lines in phosphoinfo:
+                exp.insert(tk.END, lines)
+
+    def bindinginfoadder(self):
+        window = tk.Toplevel(root)
+        window.title("Annotated Bindingpartners")
+        s = tk.Scrollbar(window)
+        exp = tk.Text(window, width=100, height=30)
+        s.pack(side=tk.RIGHT, fill=tk.Y)
+        exp.pack(side=tk.LEFT, fill=tk.Y)
+        s.config(command=exp.yview)
+        exp.config(yscrollcommand=s.set)
+        with open(
+                "./Posttranslational_modifications_and_binding_partners/Binding_partners_list.txt") as fh_binders:
+            bindinginfo = fh_binders.readlines()
+            for lines in bindinginfo:
+                exp.insert(tk.END, lines)
+
     def manual(self):
         window = tk.Toplevel(root)
         window.title("Manual for AMIVA-F")
         s = tk.Scrollbar(window)
-        exp = tk.Text(window, width=200, height=30)
+        exp = tk.Text(window, width=150, height=100)
         s.pack(side=tk.RIGHT, fill=tk.Y)
         exp.pack(side=tk.LEFT, fill=tk.Y)
         s.config(command=exp.yview)
@@ -1110,6 +1176,19 @@ class Entryfield:
         """Here we will do the wekabridging and the prediction for the mutations"""
         jvm.start()
         self.clearweka()   #remove old stuff before new entries
+        falsepredict = False    #if everything is fine this will stay false and we make a normal prediction
+
+        selfchecker = intro_form.entry1.get()  #if the first aa is the exact same as the last its obviously not pathogenic. we need to specify this case because we dont cover this case in our training set
+
+        try:
+            if intro_form.entry1.get() == "":
+                messagebox.showerror("No mutation specified above",
+                                 "You first need to fill out the form above!\nPlease specify the mutation of choice above the green button")
+                falsepredict = True   #if the entryfield is empty we dont show a prediction
+        except:
+            print(intro_form.entry1.get())
+
+
         data_dir = r"./WEKA_associated_files"
         loader = Loader(classname="weka.core.converters.ArffLoader")
         data = loader.load_file(data_dir + "/AMIVA_trainingset.arff")
@@ -1180,9 +1259,20 @@ class Entryfield:
                 self.wekaentrydomaininfo.insert(0,domaininfo)
                 self.wekaentrydomaininfo.config(font="Helvetica 18")
 
+        if falsepredict == True:     #with wrong inputs we just clear random stuff that make no sense.
+            self.clearweka()
 
-
-
+        if selfchecker[0] == selfchecker[-1]:      #if wildtype aa is mutated aa they are obviously non pathogenic... this case is although not covered in our trainingset.. we thereby specify it here.
+            self.clearweka()
+            messagebox.showinfo("No mutation inserted", "The specified mutation is the same as wildtype.")
+            self.wekaentrydis.insert(0, "benign")
+            # self.wekaentryconf.insert(0, round(values,2))
+            # self.wekaentryconf.config(font="Helvetica 18 bold")
+            self.wekaentrydis.config(foreground="green", font="Helvetica 18 bold")
+            self.wekaentryid.insert(0, parameterlist[0])
+            self.wekaentryid.config(font="Helvetica 18")
+            self.wekaentrydomaininfo.insert(0, domaininfo)
+            self.wekaentrydomaininfo.config(font="Helvetica 18")
 
         #self.wekatxt = tk.Label(self.frame6, text=intro_form.entry1.get())
         #self.wekatxt.grid(row=1, column=2, sticky="w")
@@ -1204,7 +1294,8 @@ class Entryfield:
         lstmerge = []
 
         mutfilename = self.wekaentryid.get()
-        dirtarget = "./WEKA_associated_files/" + mutfilename + ".txt"
+        savedir = filedialog.askdirectory()
+        dirtarget = savedir + "/" + mutfilename + ".txt"
         with open(dirtarget, "w", encoding="utf-8") as mutfh:
             for parameters in parameterlist:          #we will fill the parameters obtained to this new list (redundant work)
                 lstmerge.append(parameters)
@@ -1249,7 +1340,12 @@ class Entryfield:
             mutfh.write(str(evl_summary))
             mutfh.write("\n")
             mutfh.write(str(evl_class_details))
-            
+
+    def exiting_amiva(self):
+        result = messagebox.askquestion("Exit", "Do you really want to quit AMIVA-?")
+        if result == "yes":
+            root.destroy()
+
 
 
 
@@ -1308,6 +1404,8 @@ class Entryfield:
         intro_form.phosphohits = []      #new empty list for next round of mutations
         self.addinfoentry.delete(0,"end")
         intro_form.entry1.delete(0,"end")
+        entry_form.r3sidechain.configure(state="normal")
+        entry_form.r4secstr.configure(state="normal")
 
     def outfile_handler_weka(self):
         """direct prep for weka utilization"""
@@ -1381,6 +1479,7 @@ class Entryfield:
 
 
 root = tk.Tk()
+#root.geometry("700x900")
 trial = GUI(root)
 intro_form = Entry_formular(root)
 entry_form = Entryfield(root)
